@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -37,6 +37,7 @@ except AttributeError:  # pragma: NO COVER
 from google.cloud.datastore_v1.types import datastore
 from google.cloud.datastore_v1.types import entity
 from google.cloud.datastore_v1.types import query
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import DatastoreTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import DatastoreGrpcTransport
 from .transports.grpc_asyncio import DatastoreGrpcAsyncIOTransport
@@ -54,7 +55,10 @@ class DatastoreClientMeta(type):
     _transport_registry["grpc"] = DatastoreGrpcTransport
     _transport_registry["grpc_asyncio"] = DatastoreGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[DatastoreTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[DatastoreTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -166,7 +170,9 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -179,9 +185,13 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -190,9 +200,13 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -201,9 +215,13 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -212,10 +230,14 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -486,7 +508,12 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.lookup]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -549,7 +576,12 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.run_query]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -633,7 +665,12 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.begin_transaction]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -653,7 +690,6 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         r"""Commits a transaction, optionally creating, deleting
         or modifying some entities.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_v1
@@ -764,7 +800,12 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.commit]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -860,7 +901,12 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.rollback]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -878,7 +924,6 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         r"""Allocates IDs for the given keys, which is useful for
         referencing an entity before it is inserted.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_v1
@@ -958,7 +1003,12 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.allocate_ids]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -976,7 +1026,6 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         r"""Prevents the supplied keys' IDs from being
         auto-allocated by Cloud Datastore.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_v1
@@ -1055,7 +1104,12 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.reserve_ids]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1076,7 +1130,9 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-datastore",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-datastore",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
